Changelog
#########

Versions follow `Calendar Versioning`_ with the ``YYYY.M.D`` scheme.

.. _Calendar Versioning: https://calver.org

`2024.3.9`_
***********

- Add the CHANGELOG file and documentation page.
- Change the first segment locating step: don't limit it to two jumps (`#8
  <https://github.com/xymaxim/ytpb/pull/8>`__).

.. _2024.3.9: https://github.com/xymaxim/ytpb/compare/v2024.3.7..v2024.3.9
